Shared types, adapter traits, and core utilities for the Cloudillo platform.
This crate contains the foundational types that are shared between the server crate and all adapter implementations. Extracting these into a separate crate allows adapter crates to compile in parallel with the server’s feature modules.
Modules
- abac
- Attribute-based access control trait.
- action_
types - Action-related types shared between server and adapters.
- address
- Address type detection and validation for IPv4, IPv6, and hostnames
- auth_
adapter - Adapter that manages and stores authentication, authorization and other sensitive data.
- blob_
adapter - Adapter that manages and stores blobs (immutable file data)
- crdt_
adapter - CRDT Document Adapter
- error
- Error handling subsystem. Implements a custom Error type.
- extract
- Custom Axum extractors for Cloudillo-specific types.
- hasher
- Hasher format for content-addressing. Capable of handling multiple versions and object variants.
- identity_
provider_ adapter - Adapter that manages identity registration and DNS modifications.
- meta_
adapter - Adapter that manages metadata. Everything including tenants, profiles, actions, file metadata, etc.
- prelude
- rtdb_
adapter - Real-Time Database Adapter
- types
- Common types used throughout the Cloudillo platform.
- utils
- Utility functions
- worker
- Worker pool. Handles synchronous tasks with 3 priority levels, configurable worker threads.
Macros
- lock
- Helper macro for locking mutexes with automatic internal error handling.